@@ -1,7 +1,7 @@
 package Catmandu::BagIt;
 
 use strict;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Catmandu::Sane;
 use Catmandu;
@@ -1280,7 +1280,7 @@ sub _md5_sum {
 sub _is_legal_file_name {
     my ($self, $filename) = @_;
 
-    return 0 unless ($filename =~ /^[[:alnum:].-_]+$/);
+    return 0 unless ($filename =~ /^[[:alnum:]._-]+$/);
     return 0 if ($filename =~ m{(^\.|\/\.+\/)});
     return 1;
 }
